@@ -215,7 +215,8 @@ def comap(function, target):
 			mappedItem = function(*item)
 			target.send(mappedItem)
 		except Exception, e:
-			target.throw(e.__class__, e.message)
+			logging.exception("Forwarding exception!")
+			target.throw(e.__class__, str(e))
 
 
 def _flush_queue(queue):
@@ -299,11 +300,8 @@ class LoginWindow(object):
 		self._serviceCombo.add_attribute(cell, 'text', 1)
 		self._serviceCombo.set_active(0)
 
-		callbackMapping = {
-			"on_loginbutton_clicked": self._on_loginbutton_clicked,
-			"on_loginclose_clicked": self._on_loginclose_clicked,
-		}
-		widgetTree.signal_autoconnect(callbackMapping)
+		widgetTree.get_widget("loginbutton").connect("clicked", self._on_loginbutton_clicked)
+		widgetTree.get_widget("logins_close_button").connect("clicked", self._on_loginclose_clicked)
 
 	def request_credentials(self,
 		parentWindow = None,
@@ -414,9 +412,8 @@ class ErrorDisplay(object):
 			self.push_message(message)
 
 	def push_message(self, message):
-		if 0 < len(self.__messages):
-			self.__messages.append(message)
-		else:
+		self.__messages.append(message)
+		if 1 == len(self.__messages):
 			self.__show_message(message)
 
 	def push_exception_with_lock(self):
@@ -424,16 +421,16 @@ class ErrorDisplay(object):
 			self.push_exception()
 
 	def push_exception(self):
-		userMessage = str(sys.exc_value)
+		userMessage = str(sys.exc_info()[1])
 		self.push_message(userMessage)
 		logging.exception(userMessage)
 
 	def pop_message(self):
-		if 0 < len(self.__messages):
-			self.__show_message(self.__messages[0])
-			del self.__messages[0]
-		else:
+		del self.__messages[0]
+		if 0 == len(self.__messages):
 			self.__hide_message()
+		else:
+			self.__errorDescription.set_text(self.__messages[0])
 
 	def _on_close(self, *args):
 		self.pop_message()
@@ -548,7 +545,7 @@ class PopupCalendar(object):
 			self._calendar.select_month(self._displayDate.month, self._displayDate.year)
 			self._calendar.select_day(self._displayDate.day)
 		except Exception, e:
-			logging.exception(e.message)
+			logging.exception(e)
 
 
 class QuickAddView(object):
